@@ -37,47 +37,53 @@
 
 namespace zmq
 {
-class ctx_t;
-class msg_t;
-class pipe_t;
-class io_thread_t;
-class socket_base_t;
 
-class dealer_t : public socket_base_t
-{
-  public:
-    dealer_t (zmq::ctx_t *parent_, uint32_t tid_, int sid);
-    ~dealer_t ();
+    class ctx_t;
+    class msg_t;
+    class pipe_t;
+    class io_thread_t;
+    class socket_base_t;
 
-  protected:
-    //  Overrides of functions from socket_base_t.
-    void xattach_pipe (zmq::pipe_t *pipe_, bool subscribe_to_all_);
-    int xsetsockopt (int option_, const void *optval_, size_t optvallen_);
-    int xsend (zmq::msg_t *msg_);
-    int xrecv (zmq::msg_t *msg_);
-    bool xhas_in ();
-    bool xhas_out ();
-    const blob_t &get_credential () const;
-    void xread_activated (zmq::pipe_t *pipe_);
-    void xwrite_activated (zmq::pipe_t *pipe_);
-    void xpipe_terminated (zmq::pipe_t *pipe_);
+    class dealer_t :
+        public socket_base_t
+    {
+    public:
 
-    //  Send and recv - knowing which pipe was used.
-    int sendpipe (zmq::msg_t *msg_, zmq::pipe_t **pipe_);
-    int recvpipe (zmq::msg_t *msg_, zmq::pipe_t **pipe_);
+        dealer_t (zmq::ctx_t *parent_, uint32_t tid_, int sid);
+        ~dealer_t ();
 
-  private:
-    //  Messages are fair-queued from inbound pipes. And load-balanced to
-    //  the outbound pipes.
-    fq_t fq;
-    lb_t lb;
+    protected:
 
-    // if true, send an empty message to every connected router peer
-    bool probe_router;
+        //  Overrides of functions from socket_base_t.
+        void xattach_pipe (zmq::pipe_t *pipe_, bool subscribe_to_all_);
+        int xsetsockopt (int option_, const void *optval_, size_t optvallen_);
+        int xsend (zmq::msg_t *msg_);
+        int xrecv (zmq::msg_t *msg_);
+        bool xhas_in ();
+        bool xhas_out ();
+        const blob_t &get_credential () const;
+        void xread_activated (zmq::pipe_t *pipe_);
+        void xwrite_activated (zmq::pipe_t *pipe_);
+        void xpipe_terminated (zmq::pipe_t *pipe_);
+
+        //  Send and recv - knowing which pipe was used.
+        int sendpipe (zmq::msg_t *msg_, zmq::pipe_t **pipe_);
+        int recvpipe (zmq::msg_t *msg_, zmq::pipe_t **pipe_);
+
+    private:
+
+        //  Messages are fair-queued from inbound pipes. And load-balanced to
+        //  the outbound pipes.
+        fq_t fq;
+        lb_t lb;
+
+        // if true, send an empty message to every connected router peer
+        bool probe_router;
+
+        dealer_t (const dealer_t&);
+        const dealer_t &operator = (const dealer_t&);
+    };
 
-    dealer_t (const dealer_t &);
-    const dealer_t &operator= (const dealer_t &);
-};
 }
 
 #endif
