@@ -32,17 +32,13 @@
 
 #include "platform.hpp"
 
-#define __STDC_LIMIT_MACROS
+#define __STDC_LIMIT_MACROS 
 
 // This must be included before any windows headers are compiled.
 #if defined ZMQ_HAVE_WINDOWS
 #include "windows.hpp"
 #endif
 
-#if defined ZMQ_HAVE_OPENBSD
-#define ucred sockpeercred
-#endif
-
 // 0MQ definitions and exported functions
 #include "../include/zmq.h"
 
