@@ -1,17 +1,27 @@
 /*
-    Copyright (c) 2007-2014 Contributors as noted in the AUTHORS file
+    Copyright (c) 2007-2016 Contributors as noted in the AUTHORS file
 
-    This file is part of 0MQ.
+    This file is part of libzmq, the ZeroMQ core engine in C++.
 
-    0MQ is free software; you can redistribute it and/or modify it under
-    the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation; either version 3 of the License, or
+    libzmq is free software; you can redistribute it and/or modify it under
+    the terms of the GNU Lesser General Public License (LGPL) as published
+    by the Free Software Foundation; either version 3 of the License, or
     (at your option) any later version.
 
-    0MQ is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
+    As a special exception, the Contributors give you permission to link
+    this library with independent modules to produce an executable,
+    regardless of the license terms of these independent modules, and to
+    copy and distribute the resulting executable under terms of your choice,
+    provided that you also meet, for each linked independent module, the
+    terms and conditions of the license of that module. An independent
+    module is a module which is not derived from or based on this library.
+    If you modify this library, you must extend this exception to your
+    version of the library.
+
+    libzmq is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
+    License for more details.
 
     You should have received a copy of the GNU Lesser General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
@@ -31,7 +41,7 @@
 #include "poller.hpp"
 #include "atomic_counter.hpp"
 #include "i_poll_events.hpp"
-#include "mailbox.hpp"
+#include "i_mailbox.hpp"
 #include "stdint.hpp"
 #include "clock.hpp"
 #include "pipe.hpp"
@@ -66,7 +76,7 @@ namespace zmq
             uint32_t tid_, int sid_);
 
         //  Returns the mailbox associated with this socket.
-        mailbox_t *get_mailbox ();
+        i_mailbox *get_mailbox ();
 
         //  Interrupt blocking call if the socket is stuck in one.
         //  This function can be called from a different thread!
@@ -80,6 +90,8 @@ namespace zmq
         int term_endpoint (const char *addr_);
         int send (zmq::msg_t *msg_, int flags_);
         int recv (zmq::msg_t *msg_, int flags_);
+        int add_signaler (signaler_t *s);
+        int remove_signaler (signaler_t *s);
         int close ();
 
         //  These functions are used by the polling mechanism to determine
@@ -87,7 +99,11 @@ namespace zmq
         bool has_in ();
         bool has_out ();
 
-        //  Using this function reaper thread ask the socket to regiter with
+        //  Joining and leaving groups
+        int join (const char *group);
+        int leave (const char *group);
+
+        //  Using this function reaper thread ask the socket to register with
         //  its poller.
         void start_reaping (poller_t *poller_);
 
@@ -107,23 +123,29 @@ namespace zmq
 
         int monitor (const char *endpoint_, int events_);
 
-        void set_fd(fd_t fd_);
-        fd_t fd();
-
-        void event_connected (const std::string &addr_, int fd_);
+        void event_connected (const std::string &addr_, zmq::fd_t fd_);
         void event_connect_delayed (const std::string &addr_, int err_);
         void event_connect_retried (const std::string &addr_, int interval_);
-        void event_listening (const std::string &addr_, int fd_);
+        void event_listening (const std::string &addr_, zmq::fd_t fd_);
         void event_bind_failed (const std::string &addr_, int err_);
-        void event_accepted (const std::string &addr_, int fd_);
+        void event_accepted (const std::string &addr_, zmq::fd_t fd_);
         void event_accept_failed (const std::string &addr_, int err_);
-        void event_closed (const std::string &addr_, int fd_);
-        void event_close_failed (const std::string &addr_, int fd_);
-        void event_disconnected (const std::string &addr_, int fd_);
+        void event_closed (const std::string &addr_, zmq::fd_t fd_);
+        void event_close_failed (const std::string &addr_, int err_);
+        void event_disconnected (const std::string &addr_, zmq::fd_t fd_);
+        void event_handshake_failed_no_detail(const std::string &addr_, int err_);
+        void event_handshake_failed_protocol(const std::string &addr_, int err_);
+        void event_handshake_failed_auth(const std::string &addr_, int err_);
+        void event_handshake_succeeded(const std::string &addr_, int err_);
+
+        //  Query the state of a specific peer. The default implementation
+        //  always returns an ENOTSUP error.
+        virtual int get_peer_state (const void *identity,
+                                    size_t identity_size) const;
 
     protected:
 
-        socket_base_t (zmq::ctx_t *parent_, uint32_t tid_, int sid_);
+        socket_base_t (zmq::ctx_t *parent_, uint32_t tid_, int sid_, bool thread_safe_ = false);
         virtual ~socket_base_t ();
 
         //  Concrete algorithms for the x- methods are to be defined by
@@ -148,7 +170,7 @@ namespace zmq
         //  Returns the credential for the peer from which we have received
         //  the last message. If no message has been received yet,
         //  the function returns empty credential.
-        virtual blob_t get_credential () const;
+        virtual const blob_t &get_credential () const;
 
         //  i_pipe_events will be forwarded to these functions.
         virtual void xread_activated (pipe_t *pipe_);
@@ -156,19 +178,26 @@ namespace zmq
         virtual void xhiccuped (pipe_t *pipe_);
         virtual void xpipe_terminated (pipe_t *pipe_) = 0;
 
+        //  the default implementation assumes that joub and leave are not supported.
+        virtual int xjoin (const char *group_);
+        virtual int xleave (const char *group_);
+
         //  Delay actual destruction of the socket.
         void process_destroy ();
 
-        // Socket event data dispath
-        void monitor_event (int event_, int value_, const std::string& addr_);
-
-        // Monitor socket cleanup
-        void stop_monitor ();
-        
         // Next assigned name on a zmq_connect() call used by ROUTER and STREAM socket types
-        std::string connect_rid;
+        std::string connect_routing_id;
 
     private:
+        // test if event should be sent and then dispatch it        
+        void event(const std::string &addr_, intptr_t fd_, int type_);
+
+        // Socket event data dispatch
+        void monitor_event (int event_, intptr_t value_, const std::string& addr_);
+
+        // Monitor socket cleanup
+        void stop_monitor (bool send_monitor_stopped_event_ = true);
+
         //  Creates new endpoint ID and adds the endpoint to the map.
         void add_endpoint (const char *addr_, own_t *endpoint_, pipe_t *pipe);
 
@@ -221,9 +250,12 @@ namespace zmq
         void process_stop ();
         void process_bind (zmq::pipe_t *pipe_);
         void process_term (int linger_);
+        void process_term_endpoint (std::string *endpoint_);
+
+        void update_pipe_options(int option_);
 
         //  Socket's mailbox object.
-        mailbox_t mailbox;
+        i_mailbox *mailbox;
 
         //  List of attached pipes.
         typedef array_t <pipe_t, 3> pipes_t;
@@ -242,9 +274,6 @@ namespace zmq
         //  True if the last message received had MORE flag set.
         bool rcvmore;
 
-        // File descriptor if applicable
-        fd_t file_desc;
-
         //  Improves efficiency of time measurement.
         clock_t clock;
 
@@ -257,12 +286,22 @@ namespace zmq
         // Last socket endpoint resolved URI
         std::string last_endpoint;
 
+        // Indicate if the socket is thread safe
+        bool thread_safe;
+
+        // Signaler to be used in the reaping stage
+        signaler_t* reaper_signaler;
+
+        // Mutex for synchronize access to the socket in thread safe mode
+        mutex_t sync;
+
+        // Mutex to synchronize access to the monitor Pair socket
+        mutex_t monitor_sync;
+
         socket_base_t (const socket_base_t&);
         const socket_base_t &operator = (const socket_base_t&);
-        mutex_t sync;
     };
 
 }
 
 #endif
-
